/* ************************************************************************** */
/*                                       _____           _                    */
/*  p7/dump.c                           |_   _|__  _   _| |__   ___ _   _     */
/*  | Project: p7utils                    | |/ _ \| | | | '_ \ / _ \ | | |    */
/*                                        | | (_) | |_| | | | |  __/ |_| |    */
/*  By: thomas <thomas@touhey.fr>         |_|\___/ \__,_|_| |_|\___|\__, |.fr */
/*  Last updated: 2016/12/21 23:46:41                               |___/     */
/*                                                                            */
/* ************************************************************************** */
#include "main.h"
#include <inttypes.h>
#include <libp7/packetio.h>
#define numformat "%" PRIuP7INT
#define addrformat "0x%08" PRIxP7INT

/**
 *	dump:
 *	Dump calculator information.
 *
 *	@arg	handle		the libp7 handle
 *	@return				the error code (0 if ok).
 */

int dump(p7_handle_t *handle)
{
	/* get server info */
	const p7_server_t *info = p7_get_info(handle);

	/* Wiped out things */
	if (info->preprog_rom_wiped)
		log("Warning: Preprogrammed ROM information looks wiped out !\n");
	if (info->bootcode_wiped)
		log("Warning: Bootcode information looks wiped out !\n");
	if (info->os_wiped)
		log("Warning: OS information looks wiped out!\n");

	/* Preprogrammed ROM */
	if (!info->preprog_rom_wiped) {
		printf("Preprogrammed ROM capacity: " numformat "o\n",
			info->preprog_rom_capacity);
		printf("Preprogrammed ROM version: %02u.%02u.%04u\n",
			info->preprog_rom_version.major, info->preprog_rom_version.minor,
			info->preprog_rom_version.rev);
		printf("Preprogrammed ROM type: %s\n",
			info->preprog_rom_version.type);
	}

	/* ROM and RAM */
	printf("ROM capacity: " numformat "o\n", info->flash_rom_capacity);
	printf("RAM capacity: " numformat "o\n", info->ram_capacity);

	/* Bootcode */
	if (!info->bootcode_wiped) {
		printf("Bootcode version: %02u.%02u.%02u\n",
			info->bootcode_version.major, info->bootcode_version.minor,
			info->bootcode_version.rev);
		printf("Bootcode type: %s\n", info->bootcode_version.type);
		printf("Bootcode offset: " addrformat "\n", info->bootcode_offset);
		printf("Bootcode size: " numformat "o\n", info->bootcode_size);
	}

	/* OS */
	if (!info->os_wiped) {
		printf("OS version: %02u.%02u.%02u\n", info->os_version.major,
			info->os_version.minor, info->os_version.rev);
		printf("OS type: %s\n", info->os_version.type);
		printf("OS offset: " addrformat "\n", info->os_offset);
		printf("OS size: " numformat "o\n", info->os_size);
	}

	/* Miscallenous information */
	printf("Protocol version: %01u.%02u\n",
		info->protocol_version.major, info->protocol_version.minor);
	printf("Product ID: %s\n", info->product_id);
	printf("Username: %s\n", info->username);
	printf("Hardware ID: %s\n", info->hwid);
	printf("CPU ID (probably out of date): %s\n", info->cpuid);

	return (0);
}
